==> 1.1.1.tar.gz: lib/model/google_play_purchase_verification_request.dart <==
part of forestvpn_api.api;

class GooglePlayPurchaseVerificationRequest {
  /* The package name of the application that this notification relates to (for example, com.some.thing). */
  String packageName = null;
  /* The inapp product SKU (for example, 'com.some.thing.inapp1'). */
  String productId = null;
  /* The purchased subscription ID (for example, 'monthly001'). */
  String subscriptionId = null;
  /* The token provided to the user's device when the inapp product was purchased. */
  String token = null;
  GooglePlayPurchaseVerificationRequest();

  @override
  String toString() {
    return 'GooglePlayPurchaseVerificationRequest[packageName=$packageName, productId=$productId, subscriptionId=$subscriptionId, token=$token, ]';
  }

  GooglePlayPurchaseVerificationRequest.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    packageName = json['package_name'];
    productId = json['product_id'];
    subscriptionId = json['subscription_id'];
    token = json['token'];
  }

  Map<String, dynamic> toJson() {
    Map <String, dynamic> json = {};
    if (packageName != null)
      json['package_name'] = packageName;
    if (productId != null)
      json['product_id'] = productId;
    if (subscriptionId != null)
      json['subscription_id'] = subscriptionId;
    if (token != null)
      json['token'] = token;
    return json;
  }

  static List<GooglePlayPurchaseVerificationRequest> listFromJson(List<dynamic> json) {
    return json == null ? List<GooglePlayPurchaseVerificationRequest>() : json.map((value) => GooglePlayPurchaseVerificationRequest.fromJson(value)).toList();
  }

  static Map<String, GooglePlayPurchaseVerificationRequest> mapFromJson(Map<String, dynamic> json) {
    var map = Map<String, GooglePlayPurchaseVerificationRequest>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) => map[key] = GooglePlayPurchaseVerificationRequest.fromJson(value));
    }
    return map;
  }

  // maps a json object with a list of GooglePlayPurchaseVerificationRequest-objects as value to a dart map
  static Map<String, List<GooglePlayPurchaseVerificationRequest>> mapListFromJson(Map<String, dynamic> json) {
    var map = Map<String, List<GooglePlayPurchaseVerificationRequest>>();
     if (json != null && json.isNotEmpty) {
       json.forEach((String key, dynamic value) {
         map[key] = GooglePlayPurchaseVerificationRequest.listFromJson(value);
       });
     }
     return map;
  }
}

==> 1.2.1.tar.gz: lib/model/google_play_purchase_verification_request.dart <==
part of forestvpn_api.api;

class GooglePlayPurchaseVerificationRequest {
  /* The package name of the application that this notification relates to (for example, com.some.thing). */
  String packageName = null;
  /* The inapp product SKU (for example, 'com.some.thing.inapp1'). */
  String productId = null;
  /* The purchased subscription ID (for example, 'monthly001'). */
  String subscriptionId = null;
  /* The token provided to the user's device when the inapp product was purchased. */
  String token = null;
  
  String appsflyerId = null;
  GooglePlayPurchaseVerificationRequest();

  @override
  String toString() {
    return 'GooglePlayPurchaseVerificationRequest[packageName=$packageName, productId=$productId, subscriptionId=$subscriptionId, token=$token, appsflyerId=$appsflyerId, ]';
  }

  GooglePlayPurchaseVerificationRequest.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    packageName = json['package_name'];
    productId = json['product_id'];
    subscriptionId = json['subscription_id'];
    token = json['token'];
    appsflyerId = json['appsflyer_id'];
  }

  Map<String, dynamic> toJson() {
    Map <String, dynamic> json = {};
    if (packageName != null)
      json['package_name'] = packageName;
    if (productId != null)
      json['product_id'] = productId;
    if (subscriptionId != null)
      json['subscription_id'] = subscriptionId;
    if (token != null)
      json['token'] = token;
    if (appsflyerId != null)
      json['appsflyer_id'] = appsflyerId;
    return json;
  }

  static List<GooglePlayPurchaseVerificationRequest> listFromJson(List<dynamic> json) {
    return json == null ? List<GooglePlayPurchaseVerificationRequest>() : json.map((value) => GooglePlayPurchaseVerificationRequest.fromJson(value)).toList();
  }

  static Map<String, GooglePlayPurchaseVerificationRequest> mapFromJson(Map<String, dynamic> json) {
    var map = Map<String, GooglePlayPurchaseVerificationRequest>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) => map[key] = GooglePlayPurchaseVerificationRequest.fromJson(value));
    }
    return map;
  }

  // maps a json object with a list of GooglePlayPurchaseVerificationRequest-objects as value to a dart map
  static Map<String, List<GooglePlayPurchaseVerificationRequest>> mapListFromJson(Map<String, dynamic> json) {
    var map = Map<String, List<GooglePlayPurchaseVerificationRequest>>();
     if (json != null && json.isNotEmpty) {
       json.forEach((String key, dynamic value) {
         map[key] = GooglePlayPurchaseVerificationRequest.listFromJson(value);
       });
     }
     return map;
  }
}
